@@ -53,6 +53,14 @@ class Admonition(MarkdownElement):
     return _item
 
   def _render_item_complete(self, _parent, _s):
+    _ns = []
+    for _ in _s:
+      _ns += _.split("\n")
+    while _ns and not _ns[0]:
+      del _ns[0]
+    while _ns and not _ns[-1]:
+      del _ns[-1]
+    _text = "\n    " + "\n\n    ".join(_ns) + "\n" if _ns else "\n"
     if self.__title is not None:
-      return f'!!! {self.__type} "{self.__title}"\n    ' + "\n\n    ".join(_s) + "\n"
-    return f"!!! {self.__type}\n    " + "\n\n    ".join(_s) + "\n"
+      return f'\n!!! {self.__type} "{self.__title}"' + _text
+    return f"\n!!! {self.__type}" + _text
